Index: branches/FEPSimulator/FEPSim.h
===================================================================
--- branches/FEPSimulator/FEPClient.h	(revision 80)
+++ branches/FEPSimulator/FEPSim.h	(revision 82)
@@ -1,14 +1,14 @@
 /* 
- * File: FEPClient.h
+ * File: FEPSim.h
  * 
  * The FEPClient is an RPC Client which transfers network data to the
  * ATMS Server.
  *
  * An FEPClient is created every 30 seconds, and an fep_reply structure
  * for every FEP_LINE_LDS is transferred to the ATMS through an RPC Call.
  * After the FEPClient has transferred all fep_replys, it is destroyed.
  *
  * An FEPClient is script-like in nature. There are no public methods other than
  * the constructor. To construct an FEPClient, an input file (containing network 
  * data in xml form) and a host server_ip (for the ATMS) are necessary. The 
  * format of the xml input file can be fount in "networkReader.cpp" source file.
@@ -19,6 +19,6 @@
 
 // Include guard
-#ifndef __FEPCLIENT_H_INCLUDED__
-#define __FEPCLIENT_H_INCLUDED__
+#ifndef __FEPSIM_H_INCLUDED__
+#define __FEPSIM_H_INCLUDED__
 
 // Forward declared dependencies
@@ -28,9 +28,17 @@
 #include "fep.h"
 #include <iostream>
+#include <stdio.h>
 #include <stdlib.h>
 #include "time.h"
 #include "NetworkReader.h"
+#include <netdb.h>
+#include <sys/types.h> 
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <unistd.h>
 
-class FEPClient
+const int BUFF_SIZE = 1000000;
+
+class FEPSim
 {
 	public:
@@ -39,17 +47,18 @@
 
         /* methods */
-		FEPClient(char * host, char * networkFile); // Constructor
-		~FEPClient(); // Destructor
+		FEPSim(char * host, char * networkFile); // Constructor
+		~FEPSim(); // Destructor
 
 	private:
         /* members */
         NetworkReader *networkReader;
-
+        char * ATMSHost;
+        
         /* methods */
-		void handleCallResponse(void *response); //
-		void createClient(char *host);
+        void handleCallResponse(void *response); //
+        void createClient(char *host);
         void updateATMS(); // updates ATMS
 
 };
 
-#endif // __FEPCLIENT_H_INCLUDED__
+#endif // __FEPSIM_H_INCLUDED__
@@ -1,14 +1,14 @@
  * 
- * The FEPClient is an RPC Client which transfers network data to the
+ * The FEPSim is an RPC Client which transfers network data to the
  * ATMS Server.
  *
@@ -1,14 +1,14 @@
  * ATMS Server.
  *
- * An FEPClient is created every 30 seconds, and an fep_reply structure
+ * An FEPSim is created every 30 seconds, and an fep_reply structure
  * for every FEP_LINE_LDS is transferred to the ATMS through an RPC Call.
@@ -1,14 +1,14 @@
  * for every FEP_LINE_LDS is transferred to the ATMS through an RPC Call.
- * After the FEPClient has transferred all fep_replys, it is destroyed.
+ * After the FEPSim has transferred all fep_replys, it is destroyed.
  *
@@ -1,14 +1,14 @@
  *
- * An FEPClient is script-like in nature. There are no public methods other than
- * the constructor. To construct an FEPClient, an input file (containing network 
+ * An FEPSim is script-like in nature. There are no public methods other than
+ * the constructor. To construct an FEPSim, an input file (containing network 
  * data in xml form) and a host server_ip (for the ATMS) are necessary. The 
  * format of the xml input file can be fount in "networkReader.cpp" source file.
